% This is file `tuc-aushang.cls', 
%      (c) D. Wsch, Oct. 2005
% 
% Dieses Paket nimmt die Seitenrand-Einstellungen fr das TUC Corporate Design
% vor und stellt die Hausfarben zur Verfgung (RGB-Variante). Es basiert auf
% der scrartcl-Klasse.
%
% FARBEN:
%
% Diese knnen mit \color{name} bzw. \textcolor{name} verwendet werden (zur
% Verwendung von \color bzw. \textcolor siehe grfguide.ps). Die Namen sind:
%   - TUCgreen     das TUC-Grn
%   - TUCgrey1     50 % grau (Dunkelgrau)
%   - TUCgrey2     10 % grau (Hellgrau)
%   - TUCred       die rote Zierfarbe
%
% BEFEHLE:
% \includeLogo: Einbinden des Logos
%
% PAGESTYLES:
% LogoEmpty: Logo, falls die Option TUCLogo oder TUCPrintLogo eingeschaltet ist,
%            keine Seitenzahlen
% LogoPlain: Logo, falls die Option TUCLogo oder TUCPrintLogo eingeschaltet ist,
%            zentrierte Seitenzahlen
%
% Die Pagestyles knnen mit \fancypagestyle gendert werden (siehe fancyhdr-Paket).
% Als erste Seite des Dokumentes wird automatisch LogoPlain gewhlt.
%
% OPTIONEN:
%
% [TUCLogo]
% Diese Option erstellt auf der ersten Seite links oben in der Ecke das Logo,
% der rechte Rand bekommt den (schmalen) grauen Streifen. Diese Einstellung
% dient zur Online-Prsentation, da beim Laserdruck die Elemente blicherweise
% im nicht bedruckbaren Rand liegen.
%
% [TUCPrintLogo]
% Diese Option erzeugt nicht ganz CD-konforme Logos, die sich aber auf einem
% Laserdrucker drucken lassen.
%
% [TUCKeinLogo]
% Die Einrckungen werden gemacht, das Logo wird nicht gesetzt.
%
% [SchwarzWeiss] oder [SW]
% Mit dieser Option schaltet man auf S/W um (Farben und Logos).
%
% [Farbe] oder [RGB]
% Dieser Option schaltet die Farben ein. Dies ist die Standard-Einstellung.


\def\filedate{2005/13/10}
\def\fileversion{4.0.1}
\def\filename{tuc-aushang.cls}
\NeedsTeXFormat{LaTeX2e}[2001/06/01]

\ProvidesClass{tuc-aushang}[\filedate\space v\fileversion\space tuc-aushang class]

\IfFileExists{graphicx.sty}
  {\RequirePackage{graphicx}}
  {\ClassError{tuc-aushang}
    {Missing file graphicx.sty !!!}
    {Get current LaTeX2e !!!}}

\IfFileExists{color.sty}
  {\RequirePackage{color}}
  {\ClassError{tuc-aushang}
    {Missing file color.sty !!!}
    {Get current LaTeX2e !!!}}

\IfFileExists{geometry.sty}
  {\RequirePackage{geometry}}
  {\ClassError{tuc-aushang}
    {Missing file geometry.sty !!!}
    {Get current LaTeX2e !!!}}

\IfFileExists{fancyhdr.sty}
  {\RequirePackage{fancyhdr}}
  {\ClassError{tuc-aushang}
    {Missing file fancyhdr.sty !!!}
    {Get current LaTeX2e !!!}}

\IfFileExists{stone.sty}
  {\RequirePackage{stone}}
  {\ClassError{tuc-aushang}
    {Schrift Adobe Stone nicht installiert !!!}
    {Bitte installieren !!!}}

\newif\if@Farbe\@Farbetrue
\newif\if@Print\@Printfalse
\newif\if@Logo\@Logofalse

\DeclareOption{TUCLogo}{\@Logotrue\@Printfalse}
\DeclareOption{TUCPrintLogo}{\@Logotrue\@Printtrue}
\DeclareOption{TUCKeinLogo}{\@Logofalse}
\DeclareOption{SchwarzWeiss}{\@Farbefalse}\DeclareOption{SW}{\@Farbefalse}
\DeclareOption{Farbe}{\@Farbetrue}\DeclareOption{RGB}{\@Farbetrue}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{scrartcl}}
\ProcessOptions\LoadClass{scrartcl}

\if@Farbe
  \definecolor{TUCgreen}{rgb}{0,0.55,0.31}
  \definecolor{TUCgrey1}{rgb}{0.5,0.5,0.5}
  \definecolor{TUCgrey2}{rgb}{0.9,0.9,0.9}
  \definecolor{TUCred}{rgb}{0.55,0.11,0}
  \def\includeLogo{\includegraphics[height=\LogoHoehe]{Logo_TUC_de_RGB}}
\else
  \definecolor{TUCgreen}{rgb}{0,0,0}
  \definecolor{TUCgrey1}{rgb}{0,0,0}
  \definecolor{TUCgrey2}{rgb}{1,1,1}
  \definecolor{TUCred}{rgb}{0,0,0}
  \def\includeLogo{\includegraphics[height=\LogoHoehe]{Logo_TUC_de_RGB_sw}}
\fi

\newlength{\LogoHoehe}\LogoHoehe0.1143\paperwidth
\newlength{\StreifenBreite}\StreifenBreite.0571\paperwidth
\newlength{\StreifenHoeheGross}\StreifenHoeheGross\paperheight
\newlength{\StreifenHoeheKlein}\StreifenHoeheKlein\paperheight\addtolength{\StreifenHoeheKlein}{-0.5\LogoHoehe}

\geometry{left=\LogoHoehe,right=\LogoHoehe,top=1.5\LogoHoehe,bottom=1.2\LogoHoehe,ignorehead,ignorefoot,headsep=-1ex}

\newsavebox{\@GrauRechteckGross}
\newsavebox{\@GrauRechteckKlein}

\sbox{\@GrauRechteckGross}{%
  \textcolor{TUCgrey2}{\rule[-\StreifenHoeheGross]{\StreifenBreite}{\StreifenHoeheGross}}%
}%
\sbox{\@GrauRechteckKlein}{%
  \textcolor{TUCgrey2}{\rule[-\StreifenHoeheKlein]{\StreifenBreite}{\StreifenHoeheKlein}}%
}%

\newsavebox{\@TUCLogoBox}

\if@Logo
  \if@Print
    \sbox{\@TUCLogoBox}{%
    \unitlength\LogoHoehe%
      \begin{picture}(0,0)
	\put(-0.75,0.25){\includeLogo}
	\put(7,1.25){\usebox{\@GrauRechteckKlein}}
      \end{picture}%
    }%
  \else
    \sbox{\@TUCLogoBox}{%
    \unitlength\LogoHoehe%
      \begin{picture}(0,0)
	\put(-1,0.5){\includeLogo}
	\put(7.25,1.5){\usebox{\@GrauRechteckGross}}
      \end{picture}%
    }%
  \fi
\else
  \sbox{\@TUCLogoBox}{}
\fi

\fancypagestyle{LogoPlain}{
\fancyhead{}\fancyfoot{}
\fancyfoot[C]{\thepage}
\fancyhead[LE,LO]{\usebox{\@TUCLogoBox}}
\def\headrulewidth{0pt}\def\footrulewidth{0pt}
}

\fancypagestyle{LogoEmpty}{
\fancyhead{}\fancyfoot{}
\fancyhead[LE,LO]{\usebox{\@TUCLogoBox}}
\def\headrulewidth{0pt}\def\footrulewidth{0pt}
}

\thispagestyle{LogoPlain}

%%% ENDE
\endinput
